/* analysis_gdp_estimates

This file contains analysis relating earnings to gdp - Tables 2 and 3 in paper

*/

use "...\partb_dat_clean.dta", clear
merge m:1 year using "...\value_added_per_head.dta"
drop _merge


// identify main sample, to be held fixed across specs. Needs to have all these key variables to be in sample
reg log_earn_weekly1F_w log_earn_hourly1F_w log_hours1F_w female age_group pub union recession
cap gen main_sample = e(sample)

*** Table 2 GDP beta main estimates
reg log_earn_weekly1F_w loggdp1F if main_sample == 1, cluster(piden)
reg log_hours1F_w loggdp1F if main_sample == 1, cluster(piden)

reg log_earn_weekly1F_w loggdp1F loggdp1F_lag1 loggdp1F_lag2 if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
reg log_hours1F_w loggdp1F loggdp1F_lag1 loggdp1F_lag2 if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0

reg log_earn_weekly1F_w loggdp1F loggdp1F_lag1 loggdp1F_lag2 loggdp1F_lag3 if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2+loggdp1F_lag3=0
reg log_hours1F_w loggdp1F loggdp1F_lag1 loggdp1F_lag2 loggdp1F_lag3 if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2+loggdp1F_lag3=0

reg log_earn_weekly1F_w loggva1F if main_sample == 1, cluster(piden)
reg log_hours1F_w loggva1F if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w loggvapop1F if main_sample == 1, cluster(piden)
reg log_hours1F_w loggvapop1F if main_sample == 1, cluster(piden)


*** Table 3 Heterogeneity

// assign new value and variable labels where needed
cap label define age_group 1 "18-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64"
label values age_group age_group
cap label define firm_group 1 "<100" 2 "100-499" 3 "500-1999" 4 "2000+"
label values firm_group firm_group
label var union "Union"
label var public "Public"
cap label define permearn_rank 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5"
label values permearn_rank permearn_rank


reg log_earn_weekly1F_w c.loggdp1F##c.female if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##c.female c.loggdp1F_lag1##c.female c.loggdp1F_lag2##c.female if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#c.female+c.loggdp1F_lag1#c.female+c.loggdp1F_lag2#c.female=0

reg log_earn_weekly1F_w c.loggdp1F##i.age_group if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##i.age_group c.loggdp1F_lag1##i.age_group c.loggdp1F_lag2##i.age_group if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#2.age_group+c.loggdp1F_lag1#2.age_group+c.loggdp1F_lag2#2.age_group=0
test c.loggdp1F#3.age_group+c.loggdp1F_lag1#3.age_group+c.loggdp1F_lag2#3.age_group=0
test c.loggdp1F#4.age_group+c.loggdp1F_lag1#4.age_group+c.loggdp1F_lag2#4.age_group=0
test c.loggdp1F#5.age_group+c.loggdp1F_lag1#5.age_group+c.loggdp1F_lag2#5.age_group=0

reg log_earn_weekly1F_w c.loggdp1F##c.pub c.loggdp1F##c.union if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##c.pub c.loggdp1F_lag1##c.pub c.loggdp1F_lag2##c.pub c.loggdp1F##c.union c.loggdp1F_lag1##c.union c.loggdp1F_lag2##c.union if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#c.pub+c.loggdp1F_lag1#c.pub+c.loggdp1F_lag2#c.pub=0
test c.loggdp1F#c.union+c.loggdp1F_lag1#c.union+c.loggdp1F_lag2#c.union=0

reg log_earn_weekly1F_w c.loggdp1F##i.firm_group if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##i.firm_group c.loggdp1F_lag1##i.firm_group c.loggdp1F_lag2##i.firm_group if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#2.firm_group+c.loggdp1F_lag1#2.firm_group+c.loggdp1F_lag2#2.firm_group=0
test c.loggdp1F#3.firm_group+c.loggdp1F_lag1#3.firm_group+c.loggdp1F_lag2#3.firm_group=0
test c.loggdp1F#4.firm_group+c.loggdp1F_lag1#4.firm_group+c.loggdp1F_lag2#4.firm_group=0

reg log_earn_weekly1F_w c.loggdp1F##i.skill_group if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##i.skill_group c.loggdp1F_lag1##i.skill_group c.loggdp1F_lag2##i.skill_group if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#2.skill_group+c.loggdp1F_lag1#2.skill_group+c.loggdp1F_lag2#2.skill_group=0
test c.loggdp1F#3.skill_group+c.loggdp1F_lag1#3.skill_group+c.loggdp1F_lag2#3.skill_group=0

reg log_earn_weekly1F_w c.loggdp1F##i.permearn_rank if main_sample == 1, cluster(piden)
reg log_earn_weekly1F_w c.loggdp1F##i.permearn_rank c.loggdp1F_lag1##i.permearn_rank c.loggdp1F_lag2##i.permearn_rank if main_sample == 1, cluster(piden)
test loggdp1F+loggdp1F_lag1+loggdp1F_lag2=0
test c.loggdp1F#2.permearn_rank+c.loggdp1F_lag1#2.permearn_rank+c.loggdp1F_lag2#2.permearn_rank=0
test c.loggdp1F#3.permearn_rank+c.loggdp1F_lag1#3.permearn_rank+c.loggdp1F_lag2#3.permearn_rank=0
test c.loggdp1F#4.permearn_rank+c.loggdp1F_lag1#4.permearn_rank+c.loggdp1F_lag2#4.permearn_rank=0
test c.loggdp1F#5.permearn_rank+c.loggdp1F_lag1#5.permearn_rank+c.loggdp1F_lag2#5.permearn_rank=0
