/* analysis_rent_sharing

This file contains analysis relating earnings to firm shocks - Tables 4 and 5 in paper

*/

adopath + R:\ADO_files
use "...\partb_dat_clean.dta", clear

// keep sample used for rent-sharing regressions
keep if year >= 2002 & year <= 2018


*** 1 Using industry leave-one out as instrument

ivreghdfe log_earn_weekly_w (log_vapw_ardx_w = ardx_instrument_3dig), cluster(entref) first absorb(year matchFE)
cap gen main_sample = e(sample)
reghdfe log_earn_weekly_w log_vapw_ardx_w if main_sample == 1, cluster(entref) absorb(year matchFE)

***  Heterogeneity

// assign new value and variable labels where needed
cap label define age_group 1 "18-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64"
label values age_group age_group
cap label define firm_group 1 "<100" 2 "100-499" 3 "500-1999" 4 "2000+"
label values firm_group firm_group
label var union "Union"
label var public "Public"
cap label define permearn_rank 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5"
label values permearn_rank permearn_rank

reghdfe log_vapw_ardx_w ardx_instrument_3dig if main_sample == 1, cluster(entref) absorb(year matchFE)
predict fitted
reghdfe log_vapw_ardx_w log_vapw_fame if main_sample == 1, cluster(entref) absorb(year matchFE)
predict fitted1
reghdfe log_vapw_ardx_w log_vapw_ardx_w_lag if main_sample == 1, cluster(entref) absorb(year matchFE)
predict fitted2
reghdfe log_vapw_ardx_w ardx_instrument_3dig log_vapw_fame log_vapw_ardx_w_lag if main_sample == 1, cluster(entref) absorb(year matchFE)
predict fitted3

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#1.female if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#1.female = ardx_instrument_3dig c.ardx_instrument_3dig#1.female), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#1.female if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted#1.female if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted#1.female if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted#1.female if main_sample == 1, cluster(entref) absorb(year matchFE)

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#2.age_group c.log_vapw_ardx_w#3.age_group c.log_vapw_ardx_w#4.age_group c.log_vapw_ardx_w#5.age_group if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#2.age_group c.log_vapw_ardx_w#3.age_group c.log_vapw_ardx_w#4.age_group c.log_vapw_ardx_w#5.age_group = ardx_instrument_3dig c.ardx_instrument_3dig#2.age_group c.ardx_instrument_3dig#3.age_group c.ardx_instrument_3dig#4.age_group c.ardx_instrument_3dig#5.age_group), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#i.age_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted1#i.age_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted2#i.age_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted3#i.age_group if main_sample == 1, cluster(entref) absorb(year matchFE)

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#1.union if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#1.union = ardx_instrument_3dig c.ardx_instrument_3dig#1.union), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#1.union if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted1#1.union if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted2#1.union if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted3#1.union if main_sample == 1, cluster(entref) absorb(year matchFE)

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#2.firm_group c.log_vapw_ardx_w#3.firm_group c.log_vapw_ardx_w#4.firm_group if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#2.firm_group c.log_vapw_ardx_w#3.firm_group c.log_vapw_ardx_w#4.firm_group = ardx_instrument_3dig c.ardx_instrument_3dig#2.firm_group c.ardx_instrument_3dig#3.firm_group c.ardx_instrument_3dig#4.firm_group), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#i.firm_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted1#i.firm_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted2#i.firm_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted3#i.firm_group if main_sample == 1, cluster(entref) absorb(year matchFE)

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#2.skill_group c.log_vapw_ardx_w#3.skill_group if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#2.skill_group c.log_vapw_ardx_w#3.skill_group = ardx_instrument_3dig c.ardx_instrument_3dig#2.skill_group c.ardx_instrument_3dig#3.skill_group), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#i.skill_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted1#i.skill_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted2#i.skill_group if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted3#i.skill_group if main_sample == 1, cluster(entref) absorb(year matchFE)

reghdfe log_earn_weekly_w log_vapw_ardx_w c.log_vapw_ardx_w#2.permearn_rank c.log_vapw_ardx_w#3.permearn_rank c.log_vapw_ardx_w#4.permearn_rank c.log_vapw_ardx_w#5.permearn_rank if main_sample == 1, cluster(entref) absorb(year matchFE)
ivreghdfe log_earn_weekly_w (log_vapw_ardx_w c.log_vapw_ardx_w#2.permearn_rank c.log_vapw_ardx_w#3.permearn_rank c.log_vapw_ardx_w#4.permearn_rank c.log_vapw_ardx_w#5.permearn_rank = ardx_instrument_3dig c.ardx_instrument_3dig#2.permearn_rank c.ardx_instrument_3dig#3.permearn_rank c.ardx_instrument_3dig#4.permearn_rank c.ardx_instrument_3dig#5.permearn_rank), cluster(entref) first absorb(year matchFE)
reghdfe log_earn_weekly_w fitted c.fitted#i.permearn_rank if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted1 c.fitted1#i.permearn_rank if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted2 c.fitted2#i.permearn_rank if main_sample == 1, cluster(entref) absorb(year matchFE)
reghdfe log_earn_weekly_w fitted3 c.fitted3#i.permearn_rank if main_sample == 1, cluster(entref) absorb(year matchFE)

