/* clean_nespd

This file cleans the nespd dataset
*/

// set_globals needs to be run first

*** 1. Generate dataset just of firm IDs from NESPD
// note that we need to do this as main panel dataset used below doesn't contain entrefs

use piden year gpay entref using "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\ashegb_1997_2011_restricted.dta", clear
drop if piden == "" | entref == . | year == .
// duplicates. sort so that takes firm associated with highest pay.
gsort piden year -gpay entref
collapse (first) entref, by(piden year)
save "...\tmp_firmlookup0211.dta", replace

use piden year gpay entref using "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\ashe_2011_2019_gb_pens_restricted.dta", clear
drop if piden == "" | entref == . | year == .
drop if year == 2011 // take 2011 from other dataset
// duplicates. sort so that takes firm associated with highest pay.
gsort piden year -gpay entref
collapse (first) entref, by(piden year)
save "...\tmp_firmlookup1219.dta", replace

use piden year gpay entref using "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\annual\ashe_2020prov_restricted.dta", clear
drop if piden == "" | entref == . | year == .
// duplicates. sort so that takes firm associated with highest pay.
keep if year == 2020 // only want 2020 data from here
gsort piden year -gpay entref
collapse (first) entref, by(piden year)
save "...\tmp_firmlookup20.dta", replace

use "...\tmp_firmlookup0211.dta", clear
append using "...tmp_firmlookup1219.dta"
append using "...\tmp_firmlookup20.dta"
erase "...\tmp_firmlookup0211.dta"
erase "...\tmp_firmlookup1219.dta"

destring piden, replace force
destring entref, replace force

save "...\firmlookup.dta", replace

*** 2. Load main microdata (NESASHEPD 1975 - 2020)

use piden year age sex lop ft gpay gpox sic* agp thrs bhr he hexo ovpay sjd SIC07 OCC10 idbrsta idbrnemp nempgrp TPUB colag using "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\nesashepd_2019_without_nino_restricted", clear
// drop 2019 as will take from 2020 file
drop if year == 2019
append using "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\annual\ashe_2020prov_restricted.dta", keep(piden year age SEX lop LOPF ft gpay gpox sic* occ10 agp thrs bhr he hexo ovpay sjd idbrsta idbrnemp pubpriv colag empsta furlough WGOR anipay)

// generate indicator for whether pay was topped up among furloughed workers
gen paytoppedup = .
replace paytoppedup = 1 if furlough == 1
replace paytoppedup = 0 if furlough == 1 & lop == 1

// note that lop includes furlough in 2000 so change here
replace lop = LOPF if year == 2020
drop LOPF

// generate tenure (2019 and 2020 only)
tostring empsta, gen(empsta_str)
gen strlen = strlen(empsta_str)
//keep if (strlen==5 | strlen==6)
gen emp_year = substr(empsta_str,-4,.)
destring emp_year, replace
replace emp_year = . if emp_year < 1960 | emp_year > year
//drop if (emp_year<1960 | emp_year>2020)
gen emp_month = substr(empsta_str,1,1) if strlen==5
replace emp_month = substr(empsta_str,1,2) if strlen==6
destring emp_month, replace
replace emp_month = . if emp_month < 1 | emp_month > 12
gen tenure = (12*(year-emp_year))+(4-emp_month)
replace tenure = . if tenure < 0 | tenure > 1000
recode tenure (0/11=1) (12/35=2) (36/59=3) (60/119=4) (120/1000=5)
label define tenure 1 "< 1 year" 2 "1-2 years" 3 "3-4 years" 4 "5-9 years" 5 "10 years +"
label values tenure tenure
drop empsta strlen emp_year emp_month

// for some reason, all pidens missing for 2018. Need to append in separately
drop if year == 2018
append using  "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\ashe_2011_2019_gb_pens_restricted.dta", keep(piden year age sex lop ft gpay gpox sic* agp thrs bhr he hexo ovpay sjd sic07 occ10 idbrsta idbrnemp pubpriv colag wpc empsta anipay)
drop if wpc != "" & year != 2018 // use wpc variable to identify most recent append
drop wpc

// get anipay variable from smaller datasets as not in main one (note small number m:m matches)
merge m:m piden idbrnemp year using  "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\ashegb_1997_2011_restricted.dta", keepusing(anipay) update
drop if _merge == 2
drop _merge
duplicates drop

merge m:m piden idbrnemp year using  "...\6689_ASHE_17th_Ed_Nov20\stata\stata11\panel\ashe_2011_2019_gb_pens_restricted.dta", keepusing(anipay) update
drop if _merge == 2
duplicates drop
drop _merge

// unions (note very inconsistent coding over years. This is approximate)
gen union = .
replace union = 0 if year >= 2005 & colag != .
replace union = 1 if year >= 2005 & colag == 1
replace union = 1 if year >= 2005 & colag == 2
replace union = 1 if year >= 2005 & colag == 5
replace union = 0 if year >= 2004 & year < 2005 & colag != .
replace union = 1 if year >= 2004 & year < 2005 & colag >0 & colag != .
replace union = 0 if year >= 2004 & year < 2005 & colag == 403
replace union = 0 if year >= 2004 & year < 2005 & colag == 404
replace union = 1 if year < 1997 & colag != .
replace union = 0 if year < 1997 & colag == .
foreach yr in 1997 1998 2001 {
	replace union = 0 if year == `yr'
	replace union = 1 if year == `yr' & colag != .
	replace union = 0 if year == `yr' & colag == 603
	replace union = 0 if year == `yr' & colag == 604
}
foreach yr in 1999 2000 2002 2003 {
	replace union = 0 if year == `yr'
	replace union = 1 if year == `yr' & colag != .
	replace union = 0 if year == `yr' & colag == 403
	replace union = 0 if year == `yr' & colag == 404
}

// drop small number with no ID
drop if piden == ""

// some earnings units different in 2018, 2019 and 2020
foreach var of varlist he hexo  {
	replace `var' = `var'/100 if year == 2018 | year == 2019 | year == 2020
}

// make furlough indicator
gen furlough_ind = furlough == 1 & furlough != .
replace furlough_ind = 0 if furlough != 1 & furlough != .
replace furlough_ind = . if furlough == .
drop furlough
rename furlough_ind furlough

// ad hoc changes due to different variable names in 2019/2020
replace sex = SEX if sex == .
drop SEX
replace SIC07 = sic07 if SIC07 == .
drop sic07
replace OCC10 = occ10 if OCC10 == .
drop occ10

// merge in occupation-level skill data
merge m:1 OCC10 using "...\skills_clean.dta"
drop _merge

sort piden year sex
sort piden year sex
order piden year sex gpay thrs

// destring id
destring piden, replace force

//tabstat lop, by(year) // note discontinuity in this in 2005. This goes away if we ignore all jobs with zero pay

*** 3. Identify inconsistencies

*** 3.1 Identify individuals given different sexes

gen male = sex == 1
replace male = . if sex == .
egen male_pct = mean(male), by(piden) // pct male over time within id
gen mult_sex = 0
replace mult_sex = 1 if male_pct != 0 & male_pct != 1
egen male_pct_withinyear = mean(male), by(piden year)
gen mult_sex_withinyear = 0
replace mult_sex_withinyear = 1 if male_pct_withinyear != 0 & male_pct_withinyear != 1

// count number of individuals with inconsistent sexes
//preserve
//collapse (first) mult_sex, by(piden) fast
//tab mult_sex
//restore

*** 3.2 Identify individuals given different year of birth (off by more than 2 years)

gen yob = year - age - 1
egen yob_max = max(yob), by(piden)
egen yob_min = min(yob), by(piden)
gen yob_diff_max = yob_max - yob
gen yob_diff_min = yob - yob_min
gen yob_inconsistent_tmp = 0
replace yob_inconsistent_tmp = 1 if yob_diff_max > 2
replace yob_inconsistent_tmp = 1 if yob_diff_min > 2
egen yob_inconsistent = max(yob_inconsistent_tmp), by(piden)
drop *tmp

// count number of individuals with inconsistent years (by more than 2 years)
//preserve
//collapse (first) yob_inconsistent, by(piden) fast
//tab yob_inconsistent
//restore

*** 3.3 Identify individuals where either sex or year of birth have inconsistencies

gen inconsistent = 0
replace inconsistent = 1 if mult_sex == 1 | yob_inconsistent == 1

// count number with some kind of inconsistency
//preserve
//collapse (first) inconsistent, by(piden) fast
//tab inconsistent
//restore

*** 3.4 Fix records of individuals to make consistent

// Assign most common sex
replace sex = 1 if male_pct >= 0.5
replace sex = 2 if male_pct < 0.5
gen seximputed = 0
replace seximputed = 1 if male_pct >= 0.5 & mult_sex == 1
replace seximputed = 1 if male_pct < 0.5 & mult_sex == 1
drop male
gen male = .
replace male = 0 if sex == 2
replace male = 1 if sex == 1

// count number of individuals for whom we change sex variable for one or more years
//preserve
//collapse (max) seximputed, by(piden) fast
//tab seximputed
//restore

// if individuals have inconsistent yob, assign them the median year of birth
egen yob_med = median(yob), by(piden)
replace yob_med = round(yob_med)
replace yob = yob_med

// recalculate age relative to this new, unified yob to make consistent
gen age_imputed = yob != yob_med
replace age = year - yob + 1 // note weird way of calculating ages to be consistent with GID

*** 3.5 Record those where pay affected by absence

gen pay_affected = lop == 1

// replace earnings and hours as missing if loss of pay
foreach var of varlist gpay he hexo thrs {
	replace `var' = . if pay_affected == 1
}

*** 4. Aggregate across multiple jobs to worker level

// drop if >1 identical jobs (i.e. if have same earnings) (include other vars in here to make sure same ones kept each time)
sort piden year gpay age sex thrs agp bhr colag ft gpox he hexo idbrnemp idbrsta lop nempgrp OCC10 ovpay sic SIC sjd TPUB4 anipay pubpriv WGOR paytoppedup tenure
by piden year gpay: gen ind = _n
drop if ind >= 2
drop ind

// record multiple jobs in a year
sort year piden
by year piden: gen ind = [_n]
egen numjobs = max(ind), by(year piden)
drop ind

gen fulltime = ft == 1
egen numfulltimejobs = total(fulltime), by(year piden)

gen parttime = ft == 2
egen numparttimejobs = total(parttime), by(year piden)

// generate indicator for a new job
gen new_job = sjd == 2

// generate public sector indicator
gen public = 1
replace public = 0 if TPUB == 0
replace public = . if TPUB == .

// this variable is just 2018, 2019 & 2020
replace public = 0 if pubpriv == 2 | pubpriv == 3
replace public = 1 if pubpriv == 1 
drop pubpriv

// looks like a mistake for these years in TPUB
replace public = 0 if idbrsta != . & year >= 1996 & year < 2003
replace public = 1 if idbrsta == 4 & year >= 1996 & year < 2003
replace public = 1 if idbrsta == 5 & year >= 1996 & year < 2003
replace public = 1 if idbrsta == 6 & year >= 1996 & year < 2003
label var public "Public sector worker"
// note that there is a discontinuity in 1996

// a non-negligible number of jobs have zero hours but positive gpay. Possibly zhc. Set hours to missing
replace thrs = . if thrs == 0 & gpay != 0

// sort so that will take job-specific characteristics of highest paying job
gen pay_not_reported = gpay == .
replace gpay = -999 if gpay == . // code as negative earnings if earnings missing, so don't get ranked top in next sort
gsort piden year -gpay age sex thrs agp bhr colag ft gpox he hexo idbrnemp idbrsta lop nempgrp OCC10 ovpay sic SIC sjd TPUB4 anipay pub WGOR paytoppedup tenure
replace gpay = . if gpay == -999

// sum gpay and thrs over multiple jobs and collapse
collapse (sum) gpay thrs agp gpox he hexo bhr ovpay anipay (first) numfulltimejobs numparttimejobs numjobs ///
sic SIC07 public new_job seximputed idbrnemp nempgrp ///
yob_inconsistent inconsistent mult_sex age male yob pay_affected pay_not_reported ///
union skill_rank furlough paytoppedup tenure, by(piden year sex) fast

// fix fact that summing missings gives 0
replace thrs = . if thrs == 0 & gpay != 0

// sent incentive pay as missing if annual earnings missing
replace anipay = . if agp == .

// rename main earnings variables
gen earn_weekly = gpay
gen earn_annual = agp
gen earn_hourly = he
label var earn_weekly "Weekly earnings - Total (nominal)"
label var earn_annual "Annual earnings - Total (nominal)"
label var earn_annual "Hourly earnings - Total (nominal)"

// set earnings as missing if given as zero
replace earn_weekly = . if gpay == 0
replace earn_annual = . if agp == 0
replace earn_hourly = . if he == 0

label var thrs "Total hours"

// firm size
gen firm_size = .
replace firm_size = idbrnemp
label var firm_size "Number of employees in firm"

*** 5. Code industries 

gen sic1968 = sic if year < 1982
gen sic1980 = sic if year >= 1982 & year <= 1995
gen sic2003 = sic if year >= 1996 & year <= 2008
gen sic2007 = SIC07 if year > 2008

*** 5.1 sic 1968

gen sic1968_div = ""
replace sic1968_div = "Agriculture, Forestry and Fishing" if sic1968 <= 3
replace sic1968_div = "Mining and Quarrying" if sic1968 <= 109 & sic1968_div == ""
replace sic1968_div = "Food, Drink and Tobacco" if sic1968 <= 240 & sic1968_div == ""
replace sic1968_div = "Coal and Petroleum Products" if sic1968 <= 263 & sic1968_div == ""
replace sic1968_div = "Chemicals and allied industries" if sic1968 <= 279 & sic1968_div == ""
replace sic1968_div = "Metal Manufacture" if sic1968 <= 323 & sic1968_div == ""
replace sic1968_div = "Mechanical Engineering" if sic1968 <= 349 & sic1968_div == ""
replace sic1968_div = "Instrument Engineering" if sic1968 <= 354 & sic1968_div == ""
replace sic1968_div = "Electrical Engineering" if sic1968 <= 369 & sic1968_div == ""
replace sic1968_div = "Shipbuilding and marine engineering" if sic1968 <= 372 & sic1968_div == ""
replace sic1968_div = "Vehicles" if sic1968 <= 385 & sic1968_div == ""
replace sic1968_div = "Other metal goods" if sic1968 <= 399 & sic1968_div == ""
replace sic1968_div = "Textiles" if sic1968 <= 429 & sic1968_div == ""
replace sic1968_div = "Leather" if sic1968 <= 433 & sic1968_div == ""
replace sic1968_div = "Clothing and footwear" if sic1968 <= 450 & sic1968_div == ""
replace sic1968_div = "Bricks, pottery, glass, cement etc" if sic1968 <= 469 & sic1968_div == ""
replace sic1968_div = "Timber, furniture etc" if sic1968 <= 479 & sic1968_div == ""
replace sic1968_div = "Paper, printing and publishing" if sic1968 <= 489 & sic1968_div == ""
replace sic1968_div = "Other manufacturing" if sic1968 <= 499 & sic1968_div == ""
replace sic1968_div = "Construction" if sic1968 <= 500 & sic1968_div == ""
replace sic1968_div = "Gas, electricity and water" if sic1968 <= 603 & sic1968_div == ""
replace sic1968_div = "Transport and communication" if sic1968 <= 709 & sic1968_div == ""
replace sic1968_div = "Distributive trades" if sic1968 <= 832 & sic1968_div == ""
replace sic1968_div = "Insurance, banking, finance and business" if sic1968 <= 866 & sic1968_div == ""
replace sic1968_div = "Professional and scientific services" if sic1968 <= 879 & sic1968_div == ""
replace sic1968_div = "Misc services" if sic1968 <= 899 & sic1968_div == ""
replace sic1968_div = "Public admin and defence" if sic1968 <= 906 & sic1968_div == ""

encode sic1968_div, gen(sic1968_labs)
drop sic1968_div
rename sic1968_labs sic1968_div

// generate indicator for pub sector
//gen pub_ind = .
//replace pub_ind = 0 if sic1968_div != .

// make 1980 version
gen sic1980_unified = ""
replace sic1980_unified = "Agriculture, Forestry and Fishing" if sic1968_div == 1
replace sic1980_unified = "Energy and water supply" if sic1968_div == 10 | sic1968_div == 5
replace sic1980_unified = "Extraction of minerals and ores other than fuels: Manufacture of metals, mineral products and chemicals" if sic1968_div == 3 | sic1968_div == 16  | sic1968_div == 2
replace sic1980_unified = "Metal goods, engineering and vehicles" if sic1968_div == 8 | sic1968_div == 11 | sic1968_div == 14 | sic1968_div == 15 | sic1968_div == 19 | sic1968_div == 23 | sic1968_div == 27
replace sic1980_unified = "Other manufacturing" if sic1968_div == 4 | sic1968_div == 9 | sic1968_div == 13 | sic1968_div == 18 | sic1968_div == 20 | sic1968_div == 24  | sic1968_div == 25
replace sic1980_unified = "Construction" if sic1968_div == 6
replace sic1980_unified = "Distribution, hotels and catering; Repairs" if sic1968_div == 7
replace sic1980_unified = "Transport and communication" if sic1968_div == 26
replace sic1980_unified = "Banking, finance, insurance, business services and leasing" if sic1968_div == 12
replace sic1980_unified = "Other service" if sic1968_div == 17 | sic1968_div == 22  | sic1968_div == 21

*** 5.2 sic 1980

gen sic1980shorttemp = sic1980 < 1000
tostring sic1980, gen(sic1980string)
replace sic1980string = "0" + sic1980string if sic1980shorttemp == 1
gen sic1980_2dig = substr(sic1980string, 1, 2)
destring sic1980_2dig, force replace
drop sic1980string sic1980shorttemp

gen sic1980_div = ""
replace sic1980_div = "Agriculture, Forestry and Fishing" if sic1980_2dig <= 3
replace sic1980_div = "Energy and water supply" if sic1980_2dig <= 17 & sic1980_div == ""
replace sic1980_div = "Extraction of minerals and ores other than fuels: Manufacture of metals, mineral products and chemicals" if sic1980_2dig <= 26 & sic1980_div == ""
replace sic1980_div = "Metal goods, engineering and vehicles" if sic1980_2dig <= 37 & sic1980_div == ""
replace sic1980_div = "Other manufacturing" if sic1980_2dig <= 49 & sic1980_div == ""
replace sic1980_div = "Construction" if sic1980_2dig <= 50 & sic1980_div == ""
replace sic1980_div = "Distribution, hotels and catering; Repairs" if sic1980_2dig <= 67 & sic1980_div == ""
replace sic1980_div = "Transport and communication" if sic1980_2dig <= 79 & sic1980_div == ""
replace sic1980_div = "Banking, finance, insurance, business services and leasing" if sic1980_2dig <= 85 & sic1980_div == ""
replace sic1980_div = "Other services" if sic1980_2dig <= 99 & sic1980_div == ""

replace sic1980_unified = sic1980_div if year >= 1982 & year <= 1995
encode sic1980_div, gen(tmp)
drop sic1980_div
rename tmp sic1980_div

*** 5.3 sic 2003

gen sic2003shorttemp = sic2003 < 10000
tostring sic2003, gen(sic2003string)
replace sic2003string = "0" + sic2003string if sic2003shorttemp == 1
gen sic2003_2dig = substr(sic2003string, 1, 2)
destring sic2003_2dig, force replace
drop sic2003string sic2003shorttemp

gen sic2003_div = ""
replace sic2003_div = "Agriculture, Hunting, Forestry and Fishing" if sic2003_2dig <= 1
replace sic2003_div = "Mining and Quarrying" if sic2003_2dig <= 14 & sic2003_div == ""
replace sic2003_div = "Manufacturing" if sic2003_2dig <= 37 & sic2003_div == ""
replace sic2003_div = "Electricity, Gas and Water Supply" if sic2003_2dig <= 41 & sic2003_div == ""
replace sic2003_div = "Construction" if sic2003_2dig <= 45 & sic2003_div == ""
replace sic2003_div = "Wholesale trade, repair" if sic2003_2dig <= 52 & sic2003_div == ""
replace sic2003_div = "Hotels / Restaurants" if sic2003_2dig <= 55 & sic2003_div == ""
replace sic2003_div = "Transport, Storage and Communications" if sic2003_2dig <= 64 & sic2003_div == ""
replace sic2003_div = "Financial Intermediation" if sic2003_2dig <= 67 & sic2003_div == ""
replace sic2003_div = "Real Estate, Renting and Bus Activities" if sic2003_2dig <= 74 & sic2003_div == ""
replace sic2003_div = "Public Admin and Defence" if sic2003_2dig <= 75 & sic2003_div == ""
replace sic2003_div = "Education" if sic2003_2dig <= 80 & sic2003_div == ""
replace sic2003_div = "Health / Social Work" if sic2003_2dig <= 85 & sic2003_div == ""
replace sic2003_div = "Other Community, Social and Personal Service" if sic2003_2dig <= 93 & sic2003_div == ""
replace sic2003_div = "Private Household Staff" if sic2003_2dig <= 95 & sic2003_div == ""
replace sic2003_div = "Extra-territorial Organisations" if sic2003_2dig <= 99 & sic2003_div == ""

*** 5.4 sic 2007

gen sic2007shorttemp = sic2007 < 10000
tostring sic2007, gen(sic2007string)
replace sic2007string = "0" + sic2007string if sic2007shorttemp == 1
gen sic2007_2dig = substr(sic2007string, 1, 2)
destring sic2007_2dig, force replace
drop sic2007string sic2007shorttemp

gen sic2007_div = ""
replace sic2007_div = "Agriculture, Hunting, Forestry and Fishing" if sic2007_2dig <= 3
replace sic2007_div = "Mining and Quarrying" if sic2007_2dig <= 9 & sic2007_div == ""
replace sic2007_div = "Manufacturing" if sic2007_2dig <= 33 & sic2007_div == ""
replace sic2007_div = "Electricity, Gas, Steam and Air conditioning Supply" if sic2007_2dig <= 35 & sic2007_div == ""
replace sic2007_div = "Water Supply" if sic2007_2dig <= 39 & sic2007_div == ""
replace sic2007_div = "Construction" if sic2007_2dig <= 45 & sic2007_div == ""
replace sic2007_div = "Wholesale trade, repair" if sic2007_2dig <= 47 & sic2007_div == ""
replace sic2007_div = "Transport, Storage" if sic2007_2dig <= 53 & sic2007_div == ""
replace sic2007_div = "Accommodation and food service" if sic2007_2dig <= 56 & sic2007_div == ""
replace sic2007_div = "Information and communication" if sic2007_2dig <= 63 & sic2007_div == ""
replace sic2007_div = "Financial and insurance activities" if sic2007_2dig <= 66 & sic2007_div == ""
replace sic2007_div = "Real Estate" if sic2007_2dig <= 68 & sic2007_div == ""
replace sic2007_div = "Professional, Scientific and Technical" if sic2007_2dig <= 75 & sic2007_div == ""
replace sic2007_div = "Admin and support service" if sic2007_2dig <= 82 & sic2007_div == ""
replace sic2007_div = "Public admin and defence" if sic2007_2dig <= 84 & sic2007_div == ""
replace sic2007_div = "Education" if sic2007_2dig <= 85 & sic2007_div == ""
replace sic2007_div = "Health / Social Work" if sic2007_2dig <= 88 & sic2007_div == ""
replace sic2007_div = "Arts, Entertainment and recreation" if sic2007_2dig <= 93 & sic2007_div == ""
replace sic2007_div = "Other Service" if sic2007_2dig <= 96 & sic2007_div == ""
replace sic2007_div = "Private Household Staff" if sic2007_2dig <= 98 & sic2007_div == ""
replace sic2007_div = "Extra-territorial Organisations" if sic2007_2dig <= 99 & sic2007_div == ""

*** 5.5 Map sic2007 to sic2003

replace sic2003_div = "Agriculture, Hunting, Forestry and Fishing" if sic2007_div == "Agriculture, Hunting, Forestry and Fishing"
replace sic2003_div = "Mining and Quarrying" if sic2007_div == "Mining and Quarrying"
replace sic2003_div = "Manufacturing" if sic2007_div == "Manufacturing"
replace sic2003_div = "Construction" if sic2007_div == "Construction"
replace sic2003_div = "Electricity, Gas and Water Supply" if sic2007_div == "Electricity, Gas, Steam and Air conditioning Supply"
replace sic2003_div = "Electricity, Gas and Water Supply" if sic2007_div == "Water Supply"
replace sic2003_div = "Wholesale trade, repair" if sic2007_div == "Wholesale trade, repair"
replace sic2003_div = "Hotels / Restaurants" if sic2007_div == "Accommodation and food service"
replace sic2003_div = "Transport, Storage and Communications" if sic2007_div == "Transport, Storage"
replace sic2003_div = "Transport, Storage and Communications" if sic2007_div == "Information and communication"
replace sic2003_div = "Financial Intermediation" if sic2007_div == "Financial and insurance activities"
replace sic2003_div = "Real Estate, Renting and Bus Activities" if sic2007_div == "Real Estate"
replace sic2003_div = "Real Estate, Renting and Bus Activities" if sic2007_div == "Professional, Scientific and Technical"
replace sic2003_div = "Real Estate, Renting and Bus Activities" if sic2007_div == "Admin and support service"
replace sic2003_div = "Public Admin and Defence" if sic2007_div == "Public admin and defence"
replace sic2003_div = "Education" if sic2007_div == "Education"
replace sic2003_div = "Health / Social Work" if sic2007_div == "Health / Social Work"
replace sic2003_div = "Other Community, Social and Personal Service" if sic2007_div == "Arts, Entertainment and recreation"
replace sic2003_div  = "Other Community, Social and Personal Service" if sic2007_div == "Other Service"
replace sic2003_div = "Private Household Staff" if sic2007_div == "Private Household Staff"
replace sic2003_div = "Extra-territorial Organisations" if sic2007_div == "Extra-territorial Organisations"


// add to unified version
replace sic1980_unified = "Agriculture, Forestry and Fishing" if sic2003_div == "Agriculture, Hunting, Forestry and Fishing"
replace sic1980_unified = "Energy and water supply" if sic2003_div == "Electricity, Gas and Water Supply"
replace sic1980_unified = "Extraction of minerals and ores other than fuels: Manufacture of metals, mineral products and chemicals" if sic2003_div ==  "Mining and Quarrying"
replace sic1980_unified = "Metal goods, engineering and vehicles" if sic2003_div == "Manufacturing"
replace sic1980_unified = "Construction" if sic2003_div == "Construction"
replace sic1980_unified = "Distribution, hotels and catering; Repairs" if sic2003_div == "Wholesale trade, repair" | sic2003_div == "Hotels / Restaurants"
replace sic1980_unified = "Transport and communication" if sic2003_div == "Transport, Storage and Communications"
replace sic1980_unified = "Banking, finance, insurance, business services and leasing" if sic2003_div == "Financial Intermediation" | sic2003_div == "Real Estate, Renting and Bus Activities"
replace sic1980_unified = "Other service" if sic2003_div == "Public Admin and Defence" | sic2003_div == "Education" | sic2003_div == "Health / Social Work" | sic2003_div == "Other Community, Social and Personal Service" | sic2003_div == "Private Household Staff" | sic2003_div == "Extra-territorial Organisations"

// encode 2003
encode sic2003_div, gen(sic2003_divfac)
drop sic2003_div
rename sic2003_divfac sic2003_div

*** 5.6 Clean unified version

gen sic_combined = ""
replace sic_combined = "Services" if sic1980_unified == "Other service" | sic1980_unified == "Other services" | sic1980_unified == "Banking, finance, insurance, business services and leasing" | sic1980_unified == "Distribution, hotels and catering; Repairs" | sic1980_unified == "Transport and communication"
replace sic_combined = "Manufacturing" if sic1980_unified == "Metal goods, engineering and vehicles" | sic1980_unified == "Other manufacturing" | sic1980_unified ==  "Extraction of minerals and ores other than fuels: Manufacture of metals, mineral products and chemicals" | sic1980_unified == "Construction" | sic1980_unified == "Agriculture, Forestry and Fishing" | sic1980_unified == "Energy and water supply"
encode sic_combined, gen(sector)
drop sic_combined
label var sector "Broad industry sector"

*** 6. Code occupations
// Do this if decide to use occupations 

*** 8. Merge in firm IDs from other ASHE dataset

merge m:1 piden year using "...\firmlookup.dta" // m:1 is just for missings.
drop if _merge == 2
drop _merge

// generate indicator for whether new firm at t 
sort id year
by id: gen entref_l1 = entref[_n-1]
gen new_firm = .
replace new_firm = 1 if entref != entref_l1 & entref != . & entref_l1 != .
replace new_firm = 0 if entref == entref_l1 & entref != . & entref_l1 != .

*** 9. Save cleaned dataset

keep piden year age* sex yob earn* he hexo ovpay gpox bhr thrs sic1968_div sic1980_div sic2003_div ///
sic2007_div sic2007_2dig new_job sector ///
numfu numpar public male pay_affected new_firm firm_size union entref pay_not_reported skill* ///
furlough paytoppedup tenure anipay

// generate simpler ft indicator
gen ft = .
replace ft = 1 if numfulltimejobs > 0 & numfulltimejobs != .
replace ft = 0 if numfulltimejobs == 0
gen pt = 1 - ft

order piden year age yob

//generate job mover variable based on sjd in FOLLOWING period
sort piden year
by piden: gen mover = new_job[_n+1]
replace mover = . if earn_weekly == .

// age restriction (note narrower one comes in common core)
drop if age < 18 | age > 65 // course age drop

// round to make consistent over time
replace earn_weekly = round(earn_weekly, .01)
replace earn_hourly = round(earn_hourly, .01)
replace earn_annual = round(earn_annual, 1)
replace anipay = round(anipay, 1)

// make sure anipay missing if annual pay missing
replace anipay = . if earn_annual == .

save "...\nesashe7520microclean.dta", replace